#!/usr/bin/env python

'''
utils.py: general http functions (utils) for som api

'''

from som.logman import bot
from som.api.standards import (
    api_base,
    api_version
)

import requests
import os
import sys

#TODO: add retrying, ask Susan/Garrick about number of times
# (I think we should do exponential retry)


def api_get(url,headers=None,token=None,data=None):
    '''api_get will use requests to get a particular url
    :param url: the url to send file to
    :param headers: a dictionary with headers for the request
    :param putdata: additional data to add to the request
    '''
    bot.logger.debug("GET %s",url)

    if headers == None:
        headers = get_headers(token=token)
    if data == None:
        response = requests.get(url,         
                                headers=headers)
    else:
        response = requests.get(url,         
                                headers=headers,
                                data=data)
    return response


def api_put(url,headers=None,token=None,data=None):
    '''api_put will send a read file (spec) to Singularity Hub with a particular set of headers
    :param url: the url to send file to
    :param headers: the headers to get
    :param headers: a dictionary with headers for the request
    :param data: additional data to add to the request
    '''
    bot.logger.debug("PUT %s",url)

    if headers == None:
        headers = get_headers(token=token)
    if data == None:
        response = requests.put(url,         
                                headers=headers)
    else:
        response = requests.put(url,         
                                headers=headers,
                                data=data)
    
    return response


def api_post(url,headers=None,data=None,token=None):
    '''api_get will use requests to get a particular url
    :param url: the url to send file to
    :param headers: a dictionary with headers for the request
    :param data: additional data to add to the request
    '''
    bot.logger.debug("POST %s",url)

    if headers == None:
        headers = get_headers(token=token)
    if data == None:
        response = requests.post(url,         
                                 headers=headers)
    else:
        response = requests.post(url,         
                                 headers=headers,
                                 data=data)
    return response




#!/usr/bin/env python

'''
standards.py: lists of standard things to be used with validators

'''

from som.logman import bot

# Sources (lists) of valid identifiers
person_sources = ['stanford']
item_sources = ['pacs']



#!/usr/bin/env python

'''
base.py: base module for working with som api

'''

from som.logman import bot
from som.auth import (
    authenticate,
    get_headers
)

from som.api.utils import (
    api_get,
    api_post,
    api_put
)

from som.api.base import (
    api_base,
    api_version,
    create_identifiers
)

from som.api.validators.requests import validate_person

def get_radiology_base(base=None,version=None):
    '''get_radiology_base returns the base api for radiology
    :param base: if base URL. If not defined, will use default
    :param version: the api version, in format vX. If not defined,
    will return default
    '''
    if base == None:
        base = api_base
    if version == None:
        version = api_version

    return "%s/radiology/api/%s" %(base,version)


def deidentify(item_id,item_id_source,item_id_timestamp,
               person=None,person_id=None,person_id_source=None,person_id_timestamp=None,
               person_sources=None,person_custom_fields=None,
               item_custom_fields=None,item_sources=None,               
               base=None,version=None,headers=None,verbose=False):
    '''deidentify will send a post to deidentify one or more images
    POST https://APIBASE/radiology/api/APIVERSION/deidentify    

    PERSON
    :param person_id: mandatory key for uniquely identifying the person (e.g. "1234567-8")
    :param person_id_source: mandatory issuer for the above id (e.g., "stanford")
    :param person_id_timestamp: when the id was looked up, to help with changed/merged ids (optional)
    :param person_custom_fields: not required, a dictionary of custom key pairs to include as data
    :param person: if provided, the other fields are not required

    ITEMS
    :param item_id: mandatory key for uniquely identifying the person (e.g. "1234567-8")
    :param item_id_source: mandatory issuer for the above id (e.g., "stanford")
    :param item_id_timestamp: when the id was looked up, to help with changed/merged ids (optional)
    :param item_custom_fields: not required, a list or dictionar of custom key pairs to include as data

    OPTIONAL
    :param person_sources: a custom list of sources (eg, ['stanford']) to accept. If not defined, defaults
    :param base: if base URL. If not defined, will use default
    :param version: the api version, in format vX. If not defined,
    :param headers: a dictionary with headers for the request
    :param verbose: True will print successful items as well (default is False)

    ::notes: default behavior is to exit if the person returns as None, indicating not valid
             error messages (reasons for not valid) are printed by validation functions.

             the same default is used for items. We don't want one item going through and missing
             another (invalid) and then needing to try again.
    '''

    headers = get_headers(token=token)  #TODO: customize this depending
                                        # on whether token required, how passed, etc.

    # Prepare response urls
    base = get_radiology_base(base,version)
    url = "%s/deidentify" %(base)
    bot.logger.debug("POST %s",url)

    # Prepare data
    if person == None:
        person = create_person(person_id=person_id,
                               id_source=person_id_source,
                               id_timestamp=person_id_timestamp,
                               custom_fields=person_custom_fields,
                               sources=person_sources) #verbose True
    else:
        if validate_person(person,sources=person_id_source) == False:
            person = None

    if person == None:
        bot.logger.error("Person not successfully created. Exiting.")
        sys.exit(1)

    # This function requires items, if not needed, should just create person
    items = create_items(item_ids=item_ids,
                         id_sources=item_id_sources,
                         sources=item_sources,
                         custom_fields=item_custom_fields,
                         verbose=verbose)

    identifiers = create_identifiers(person=person,items=items)
    data = {"identifiers":identifiers }

    return api_post(url,headers=headers,data=data)



#!/usr/bin/env python

'''
auth.py: authentication functions for som api

'''

from som.logman import bot
from som.api.base import (
    api_base,
    api_get,
    api_post,
    api_put,
    api_version
)

from som.api.utils import (
    api_get,
    api_post,
    api_put
)

from som.utils import (
    read_file
)

import os


def authenticate(domain=None,token_folder=None):
    '''authenticate will authenticate the user with the SOM api. This means
    either obtaining the token from the environment, and then trying to obtain
    the token file and reading it, and then finally telling the user to get it.
    :param domain: the domain to direct the user to for the token, default is api_base
    :param token_folder: the location of the token file, default is $HOME (~/)
    '''
    #TODO: we may/may not want a client to hold an authentication object

    # Attempt 1: Get token from environmental variable
    token = os.environ.get("STANFORD_SOM_TOKEN",None)

    if token == None:
        # Is the user specifying a custom home folder?
        if token_folder == None:
            token_folder = os.environ["HOME"]

        token_file = "%s/.somapi" %(token_folder)
        if os.path.exists(token_file):
            token = read_file(token_file)[0].strip('\n')
        else:
            if domain == None:
                domain = api_base
            print('''Please obtain token from %s/token
                     and save to .somtoken in your $HOME folder''' %(domain))
            sys.exit(1)
    return token


def get_headers(token=None):
    '''get_headers will return a simple default header for a json
    post. This function will be adopted as needed.
    :param token: an optional token to add for auth
    '''
    headers = dict()
    if token!=None:
        headers["Authentication"] = "Token %s" %(token)
    headers["Content-Type"] = "application/json"
    bot.logger.debug("Headers found: %s",headers)
    return headers



#!/usr/bin/env python

'''
validators/requests.py: validation of json (dict) structures to send

'''

from som.logman import bot
from som.api.base import (
    person_sources,
    item_sources
)

import os
import sys

from validator import (
    Required, 
    Not, 
    Truthy, 
    Blank, 
    Range, 
    Equals, 
    In, 
    validate
)


def validate_person(person,sources=None):
    '''validate_person will validate a person object, intended to go in as a field to
    a POST
    :param person: the person object. Must include the following:
    :param sources: a list of one or more person sources. If not default, use standards
    defaults

    :: notes
      "person":{
        # mandatory key for uniquely identifying the person
        "id":"1234567-8",
        # the issuer for the above id
        # mandatory, or maybe optional with default of "stanford" or "unspecified"
        "id_source":"stanford",
        # when the id was looked up, to help with changed/merged ids
        # optional with default of current timestamp?
        "id_timestamp":"2016-01-30T17:15:23.123Z",
        # optional key/value attributes, will be stored as-is if provided, but not used or interpreted
        # values will be updated/replaced if sent multiple times (last received wins)
        # any existing values will be preserved if not explicitly set here; set empty string to remove
        "custom_fields":{
          "first_name":"Joe",
          "last_name":"Smith",
          "dob":"1970-02-28"
        }
    '''
    if sources == None:
        sources = person_sources

    # These are the rules for a person
    rules = {
        "id": [Required, Pattern("^[A-Za-z0-9_-]*$")], # pattern
        "id_source": [Required, In(person_sources)],   # must be in person sources
        "id_timestamp": [Required,XXX], 
        "custom_fields":[]
    }

    valid,message = validate(rules, person)
    bot.logger.debug("Person data structure valid: %s",valid)
    if valid == False:
        bot.logger.error(message)
    return valid


def validate_items(items,sources=None,verbose=True):
    '''validate_items is a wrapper for "validate_item" to allow for one or more items
    to go through validation at once.
    :param items: one or more items to parse through, a dict or list of dicts
    :param verbose: if True, will output each item that is valid
    '''
    if not isinstance(items,list):
        items = [items]

    for item in items:
        valid = validate_item(item=item,
                              sources=sources,
                              verbose=verbose)
 
        # We stop mid point if we find an invalid item
        if valid == False:
            return valid
 
    # Otherwise, we return all items valid
    return valid


def validate_item(item,sources=None,verbose=True):
    '''validate_item will validate a single item objects, intended to go in as a field to
    a POST. For more than one item, use validate_items wrapper
    :param item: the item object. Must include the following:
    :param sources: a list of valid item sources (eg ["pacs"])
    :param verbose: if True, prints out valid True messages. False (errors) always printed

    :: notes

      "item":{
        # generic attribute/values just to store, not interpreted
        "id":"123123123123123", // mandatory
        # the issuer for the above id
        # mandatory, or maybe optional with default of "stanford" or "unspecified"
        "id_source":"pacs",
        # when the id was looked up, to help with changed/merged ids
        # optional with default of current timestamp?
        "id_timestamp":"2016-01-30T17:15:23.123Z",
        # optional date (format "yyyy-mm-dd") or timestamp for this item's "business date"
        # if this is provided a "fuzzed" value for it will be returned in the response
        # person must be provided if this is provided (because the fuzzing is an offset for the person)
        "effective_timestamp":"2016-01-30T17:15:23.123Z",
        # optional key/value attributes, will be stored as-is if provided, but not used or interpreted
        # values will be updated/replaced if sent multiple times (last received wins)
        # any existing values will be preserved if not explicitly set here; set empty string to remove
        "custom_fields":{
          "image_type":"x-ray",
          "resolution":"high"
        }
      }
    '''
    if sources == None:
        sources = item_sources

    # These are the rules for an item
    rules = {
        "id": [Required, Pattern("^[A-Za-z0-9_-]*$")], # pattern
        "id_source": [Required, In(item_sources)],      # must be in item sources
        "id_timestamp": [Required,"xxx"], 
        "effective_timestamp":[],
        "custom_fields":[]
    }

    valid,message = validate(rules, item)
    if verbose == True:
        bot.logger.debug("Person data structure valid: %s",valid)
    if valid == False:
        bot.logger.error(message)
    return valid



__version__ = "0.0.1"
AUTHOR = 'Vanessa Sochat'
AUTHOR_EMAIL = 'vsochat@stanford.edu'
NAME = 'som'
PACKAGE_URL = "https://github.com/radinformatics/somtools"
KEYWORDS = 'medical-images, stanford, school of medicine, api, validator'
DESCRIPTION = "python tools for school of medicine"
LICENSE = "LICENSE"

INSTALL_REQUIRES = (

    ('flask', {'min_version': '0.12'}),
    ('flask-restful', {'min_version': None}),
    ('pandas', {'min_version': '0.19.2'}),
    ('requests', {'min_version': '2.12.4'}),
    ('retrying', {'min_version': '1.3.3'}),
    ('selenium', {'min_version': '3.0.2'}),
    ('simplejson', {'min_version': '3.10.0'}),
    ('pygments', {'min_version': '2.1.3'}),
    ('validator.py',{'min_version': None }),
    ('google-api-python-client', {'min_version': None}),
    ('oauth2client', {'exact_version': '3.0'})
)



#!/usr/bin/env python

'''
validators/responses.py: validation of json responses from api

'''

from som.logman import bot
import os
import sys

from validator import (
    Required, 
    Not, 
    Truthy, 
    Blank, 
    Range, 
    Equals, 
    In, 
    validate
)


def receive_identifiers(response):
    '''receive identifiers will validate reception of an identifiers response
    :param response: the response object

    :: notes
     successful response:

     HTTP 200
    {
      "identifiers": [
      {
         // present if and only if person was in request
         // same person id+source in --> same id here
         "person_opaque_id":"SP123abc123abc...",
         // present if and only if item was in request
         // same id+source in --> same id here
         "item_opaque_id":"ST234def234def...",
         // present if and only if effective_timestamp was provided
         // precision will match that provided in the request
         // timestamp will be shifted by a random offset for the person so 
         // all items for a given person will have the same offset
         "fuzzed_effective_timestamp":"2016-01-30T17:15:23.123Z"
        },
       ...
      ]
     }
    '''
    bot.logger.debug("NOT YET WRITTEN")
    return True



#!/usr/bin/env python

'''
validators/utils.py: utility functions for validators

'''

from som.logman import bot
import os
import sys

def get_universal_source(source,comparator):
    '''get universal source will, given a source item (a list or single item), check to
    see if the length of a comparator is equivalent. The comparator is expected to be a list
    the same length as the source.
    :param source: the source item (single item or list)
    :param comparator: the thing to compare to
    :returns: EITHER a universal source (meaning one item to use for all items in source) OR None,
    meaning the comparator should be treated as a list, and source[i] matched to comparator[i]
    '''
    universal_source = None
    if isinstance(source,list):
        if len(source) != len(comparator):
            bot.logger.error("Mismatch in length of source (%s) and comparator (%s). Exiting",
                                                               len(source),len(comparator))
            sys.exit(1)
    else:
        # Otherwise, we assume a common source
        universal_source = id_sources
    return universal_source



#!/usr/bin/env python

'''
utils.py: part of som package

'''

import collections
import fnmatch
import os
import json
import re
import requests

import shutil
import simplejson
import som.__init__ as hello
from som.logman import bot
import sys

import subprocess

import tempfile
import tarfile
import zipfile


# Python less than version 3 must import OSError
if sys.version_info[0] < 3:
    from exceptions import OSError


######################################################################################
# Local commands and requests
######################################################################################

def get_installdir():
    '''get_installdir returns the installation directory of the application
    '''
    return os.path.abspath(os.path.dirname(hello.__file__))


def run_command(cmd,error_message=None,sudopw=None,suppress=False):
    '''run_command uses subprocess to send a command to the terminal.
    :param cmd: the command to send, should be a list for subprocess
    :param error_message: the error message to give to user if fails, 
    if none specified, will alert that command failed.
    :param execute: if True, will add `` around command (default is False)
    :param sudopw: if specified (not None) command will be run asking for sudo
    '''
    if sudopw == None:
        sudopw = os.environ.get('pancakes',None)

    if sudopw != None:
        cmd = ' '.join(["echo", sudopw,"|","sudo","-S"] + cmd)
        if suppress == False:
            output = os.popen(cmd).read().strip('\n')
        else:
            output = cmd
            os.system(cmd)
    else:
        try:
            process = subprocess.Popen(cmd,stdout=subprocess.PIPE)
            output, err = process.communicate()
        except OSError as error: 
            if error.errno == os.errno.ENOENT:
                bot.logger.error(error_message)
            else:
                bot.logger.error(err)
            return None
    
    return output


############################################################################
## FILE OPERATIONS #########################################################
############################################################################

def write_file(filename,content,mode="w"):
    '''write_file will open a file, "filename" and write content, "content"
    and properly close the file
    '''
    with open(filename,mode) as filey:
        filey.writelines(content)
    return filename


def write_json(json_obj,filename,mode="w",print_pretty=True):
    '''write_json will (optionally,pretty print) a json object to file
    :param json_obj: the dict to print to json
    :param filename: the output file to write to
    :param pretty_print: if True, will use nicer formatting   
    '''
    with open(filename,mode) as filey:
        if print_pretty == True:
            filey.writelines(simplejson.dumps(json_obj, indent=4, separators=(',', ': ')))
        else:
            filey.writelines(simplejson.dumps(json_obj))
    return filename


def read_file(filename,mode="r"):
    '''write_file will open a file, "filename" and write content, "content"
    and properly close the file
    '''
    with open(filename,mode) as filey:
        content = filey.readlines()
    return content



def read_json(filename,mode="r"):
    '''read_json will open a file, "filename" and read the string as json
    '''
    with open(filename,mode) as filey:
        content = json.loads(filey.read())
    return content


############################################################################
## COMPRESSED FILES ########################################################
############################################################################


def detect_compressed(folder,compressed_types=None):
    '''detect compressed will return a list of files in 
    some folder that are compressed, by default this means
    .zip or .tar.gz, but the called can specify a custom list
    :param folder: the folder base to use.
    :param compressed_types: a list of types to include, should
    be extensions in format like *.tar.gz, *.zip, etc.
    '''
    compressed = []
    if compressed_types == None:
        compressed_types = ["*.tar.gz",'*zip']
    bot.logger.debug("Searching for %s",", ".join(compressed_types))

    for filey in os.listdir(folder):
        for compressed_type in compressed_types:
            if fnmatch.fnmatch(filey, compressed_type):
                compressed.append("%s/%s" %(folder,filey))
    bot.logger.debug("Found %s compressed files in %s",len(compressed),folder)
    return compressed


def unzip_dir(zip_file,dest_dir=None):
    '''unzip_dir will extract a zipfile to a directory. If
    an extraction destination is not defined, a temporary
    directory will be created and used.
    :param zip_file: the .zip file to unzip
    :param dest_dir: the destination directory
    '''

    if dest_dir == None:
        dest_dir = tempfile.mkdtemp()

    with zipfile.ZipFile(zip_file,"r") as zf:
        zf.extractall(dest_dir)
    return dest_dir



def zip_dir(zip_dir, zip_name, output_folder=None):
    '''zip_dir will zip up and entire zip directory
    :param folder_path: the folder to zip up
    :param zip_name: the name of the zip to return
    :output_folder:
    '''
    tmpdir = tempfile.mkdtemp()
    output_zip = "%s/%s" %(tmpdir,zip_name)
    zf = zipfile.ZipFile(output_zip, "w", zipfile.ZIP_DEFLATED, allowZip64=True)
    for root, dirs, files in os.walk(zip_dir):
        for file in files:
            zf.write(os.path.join(root, file))
    zf.close()
    if output_folder != None:
        shutil.copyfile(output_zip,"%s/%s"%(output_folder,zip_name))
        shutil.rmtree(tmpdir)
        output_zip = "%s/%s"%(output_folder,zip_name)
    return output_zip



def untar_dir(tar_file,dest_dir=None):
    '''untar_dir will extract a tarfile to a directory. If
    an extraction destination is not defined, a temporary
    directory will be created and used.
    :param tar_file: the .tar.gz file to untar/decompress
    :param dest_dir: the destination directory
    '''

    if dest_dir == None:
        dest_dir = tempfile.mkdtemp()

    contents = []
    if tarfile.is_tarfile(tar_file):
        with tarfile.open(tar_file) as tf:
            tf.extractall(dest_dir)
    return dest_dir



from flask import (
    Flask, 
    render_template, 
    request
)

from flask_restful import Resource, Api
from werkzeug import secure_filename
import webbrowser
import tempfile
import shutil
import random
import os

# SERVER CONFIGURATION ##############################################
class SomServer(Flask):

    def __init__(self, *args, **kwargs):
        super(SomServer, self).__init__(*args, **kwargs)

        # Set up temporary directory on start of application
        self.tmpdir = tempfile.mkdtemp()
        self.images = None # List of images for visualization


# API VIEWS #########################################################
# eventually we can have views or functions served in this way...

app = SomServer(__name__)
#api = Api(app)    
#api.add_resource(apiExperiments,'/experiments')
#api.add_resource(apiExperimentSingle,'/experiments/<string:exp_id>')

# BAR PLOTS TO COMPARE TO PACKAGES #################################
@app.route('/som/annotate')
def annotate_images():
    return render_template('annotate_images.html')


# START FUNCTIONS ##################################################
    
# Function to make single package/image tree
def make_tree(image,port=None,sudopw=None):
    app.image = image
    app.sudopw = sudopw
    if port==None:
        port=8088
    print("It goes without saying. I suspect now it's not going.")
    webbrowser.open("http://localhost:%s/container/tree" %(port))
    app.run(host="0.0.0.0",debug=False,port=port)


# Function to make bar chart to compare to os
def plot_os_sims(image,port=None,sudopw=None):
    app.image = image
    app.sudopw = sudopw
    if port==None:
        port=8088
    print("The not remembering is part of the disability, my dear fish.")
    webbrowser.open("http://localhost:%s/container/os" %(port))
    app.run(host="0.0.0.0",debug=False,port=port)


# Function to make similar tree to compare images
def make_sim_tree(image1,image2,port=None):
    app.images = [image1,image2]
    if port==None:
        port=8088
    print("The recipe for insight can be reduced to a box of cereal and a Sunday afternoon.")
    webbrowser.open("http://localhost:%s/containers/similarity" %(port))
    app.run(host="0.0.0.0",debug=False,port=port)

# Function to make difference tree for two images
def make_diff_tree(image1,image2,port=None):
    app.images = [image1,image2]
    if port==None:
        port=8088
    print("Pandas... just let them go.")
    webbrowser.open("http://localhost:%s/containers/subtract" %(port))
    app.run(host="0.0.0.0",debug=True,port=port)


if __name__ == '__main__':
    app.debug = True
    app.run(host='0.0.0.0')



#!/usr/bin/env python

import dicom
import nibabel
import numpy
from glob import glob
import os
from som.logman import bot


def find_dicoms(folder,extension=None):
    '''find_dicoms will walk a directory structure and find dicoms in subfolders
    :param folder: the parent folder to look in
    :param extension: the extension to use. Default is .dcm
    '''
    folders = dict()

    if extension == None:
        extension = ".dcm"

    for dirpath, dirnames, filenames in os.walk(folder):
        dicoms = []
        for filename in [f for f in filenames if f.endswith(extension)]:
            dicoms.append(os.path.join(dirpath, filename))
        if len(dicoms) > 0:
            folders[dirpath] = dicoms
    bot.logger.debug('Found %s directories with dicom.', len(folders))
    return folders


def sniff_header(dicom_file):
    '''sniff_header will return an estimated affine, x,y,z dimension from
    the first image (or any) in a series of dicom
    '''
    header = dict()
    ds = dicom.read_file(dicom_file)
    header['xdim'] = ds.Rows
    header['ydim'] = ds.Columns
    header['window_center'] = int(ds.WindowCenter)
    return header
    

def read_series(dicoms,return_nifti=True):
    '''read_series will read in a series of dicoms belonging to a group
    :param dicoms: a list of dicom files to parse, assumed in same series and
    equal size
    :param return_nifti: If True (default) will turn image as Nifti File
    '''
    # Sort the dicoms
    dicoms.sort()

    # Get the size of the image
    params = sniff_header(dicoms[0])
    xdim = params['xdim']
    ydim = params['ydim']   
    windom_center = params['window_center']
 
    bot.logger.debug("First dicom found with dimension %s by %s, using as standard.", xdim,ydim)

    # Let's get ordering of images based on InstanceNumber
    ordered = dict()
    for d in range(len(dicoms)):    
        ds = dicom.read_file(dicoms[d])
        if ds.Rows == xdim and ds.Columns == ydim:
            ordered[int(ds.InstanceNumber)] = ds.pixel_array

    # Sort by order
    zdim = len(ordered)    
    data = numpy.ndarray((xdim,ydim,zdim))

    # Start at window center, then go back to zero
    index = 0
    for key in sorted(ordered.keys()):
        data[:,:,index] = ordered[key]
        index +=1
    
    if return_nifti == True:
        affine = numpy.diag((1,1,1,0))
        data = nibabel.Nifti1Image(data,affine=affine)
    return data


def dicom2nifti(folders,outdir=None,extension=None):
    '''dicom2nifti will take a list of folders and produce nifti files
    in an output directory. If not defined, they will be output in their
    original directory.
    '''
    if isinstance(folders,dict):
        folders = list(folders.keys())
    
    if not isinstance(folders,list):
        folders = [folders]

    outfiles = []
    for folder in folders:
        lookup = find_dicoms(folder,extension)
        for base,dicomlist in lookup.items():
            nii = read_series(dicomlist)
            if outdir != None:
                outfile = "%s/%s.nii.gz" %(outdir,os.path.basename(base))
            else:
                outfile = "%s/%s.nii.gz" %(base,os.path.basename(base))
            bot.logger.info("Saving %s", outfile)
            nibabel.save(nii,outfile)
            outfiles.append(outfile)
    return outfiles


if __name__ == '__main__':
    folder = os.getcwd()
    dicoms = find_dicoms(folder)



import logging
import os
import sys

class Logman:

    def __init__(self,stream=True,MESSAGELEVEL=None):
        self.level = get_logging_level(MESSAGELEVEL)
        if stream == True:
            logging.basicConfig(stream=sys.stdout,level=self.level)
        else:
            logging.basicConfig(level=self.level)
        self.logger = logging.getLogger('som')
        self.formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')


def get_logging_level(MESSAGELEVEL=None):
    '''get_logging_level will return a logging level based on first
    a variable going into the function, then an environment variable
    MESSAGELEVEL, and then the default is DEBUG.
    :param MESSAGELEVEL: the level to get.
    '''
    if MESSAGELEVEL == None:
        MESSAGELEVEL = os.environ.get("MESSAGELEVEL","DEBUG")

    if MESSAGELEVEL in ["DEBUG","INFO"]:
        print("Environment message level found to be %s" %MESSAGELEVEL)

    if MESSAGELEVEL == "FATAL":
        return logging.FATAL

    elif MESSAGELEVEL == "CRITICAL":
        return logging.CRITICAL

    elif MESSAGELEVEL == "ERROR":
        return logging.ERROR

    elif MESSAGELEVEL == "WARNING":
        return logging.WARNING

    elif MESSAGELEVEL == "INFO":
        return logging.INFO

    elif MESSAGELEVEL in "DEBUG":
        return logging.DEBUG

    return logging.DEBUG

bot = Logman()
